@@ -2,9 +2,9 @@
 
 import warnings
 
-warnings.warn("We will remove this module from nibabel soon; "
+warnings.warn("We will remove this module from nibabel 3.0; "
               "Please use the 'minc1' module instead",
-              FutureWarning,
+              DeprecationWarning,
               stacklevel=2)
 
 from .minc1 import *  # noqa
