@@ -19,6 +19,7 @@ import numpy as np
 import numpy.linalg as npl
 
 from .py3k import asstr
+from .filebasedimages import SerializableImage
 from .volumeutils import Recoder, make_dt_codes, endian_codes
 from .spatialimages import HeaderDataError, ImageFileError
 from .batteryrunners import Report
@@ -27,7 +28,6 @@ from . import analyze  # module import
 from .spm99analyze import SpmAnalyzeHeader
 from .casting import have_binary128
 from .pydicom_compat import have_dicom, pydicom as pdcm
-from . import setup_test  # noqa
 
 # nifti1 flat header definition for Analyze-like first 348 bytes
 # first number in comments indicates offset in file header in bytes
@@ -2025,7 +2025,7 @@ class Nifti1Pair(analyze.AnalyzeImage):
         return img
 
 
-class Nifti1Image(Nifti1Pair):
+class Nifti1Image(Nifti1Pair, SerializableImage):
     """ Class for single file NIfTI1 format image
     """
     header_class = Nifti1Header
