@@ -32,6 +32,7 @@ def setup():
                                                 "simple_big_endian.tck")
     # standard.tck contains only streamlines
     DATA['standard_tck_fname'] = pjoin(data_path, "standard.tck")
+    DATA['matlab_nan_tck_fname'] = pjoin(data_path, "matlab_nan.tck")
 
     DATA['streamlines'] = [np.arange(1 * 3, dtype="f4").reshape((1, 3)),
                            np.arange(2 * 3, dtype="f4").reshape((2, 3)),
@@ -64,6 +65,13 @@ class TestTCK(unittest.TestCase):
         tck = TckFile(tractogram, header=hdr)
         assert_tractogram_equal(tck.tractogram, DATA['simple_tractogram'])
 
+    def test_load_matlab_nan_file(self):
+        for lazy_load in [False, True]:
+            tck = TckFile.load(DATA['matlab_nan_tck_fname'], lazy_load=lazy_load)
+            streamlines = list(tck.tractogram.streamlines)
+            assert_equal(len(streamlines), 1)
+            assert_equal(streamlines[0].shape, (108, 3))
+
     def test_writeable_data(self):
         data = DATA['simple_tractogram']
         for key in ('simple_tck_fname', 'simple_tck_big_endian_fname'):
