@@ -2,7 +2,8 @@
 
 from ..keywordonly import kw_only_func, kw_only_meth
 
-from nose.tools import assert_true, assert_false, assert_equal, assert_raises
+from nose.tools import assert_equal
+from nose.tools import assert_raises
 
 
 def test_kw_only_func():
@@ -17,6 +18,7 @@ def test_kw_only_func():
     assert_raises(TypeError, dec_func, 1, 2)
     assert_raises(TypeError, dec_func, 1, akeyarg=3)
     assert_equal(dec_func.__doc__, 'My docstring')
+
     @kw_only_func(1)
     def kw_func(an_arg, a_kwarg='thing'):
         "Another docstring"
@@ -26,7 +28,9 @@ def test_kw_only_func():
     assert_equal(kw_func(1, a_kwarg=2), (1, 2))
     assert_raises(TypeError, kw_func, 1, akeyarg=3)
     assert_equal(kw_func.__doc__, 'Another docstring')
+
     class C(object):
+
         @kw_only_meth(1)
         def kw_meth(self, an_arg, a_kwarg='thing'):
             "Method docstring"
