@@ -30,7 +30,7 @@ from nibabel.eulerangles import euler2mat
 
 from numpy.testing import (assert_almost_equal,
                            assert_array_equal)
-from numpy.testing.decorators import skipif
+from ..testing import skipif
 
 from nose.tools import (assert_true, assert_false, assert_raises,
                         assert_equal, assert_not_equal)
