@@ -67,6 +67,40 @@ def check_nib_ls_example4d(opts=[], hdrs_str="", other_str=""):
     assert_equal(fname, stdout[:len(fname)])
     assert_re_in(expected_re, stdout[len(fname):])
 
+
+def check_nib_diff_examples():
+    fnames = [pjoin(DATA_PATH, f)
+               for f in ('standard.nii.gz', 'example4d.nii.gz')]
+    code, stdout, stderr = run_command(['nib-diff'] + fnames, check_code=False)
+    checked_fields = ["Field/File", "regular", "dim_info", "dim", "datatype", "bitpix", "pixdim", "slice_end",
+                      "xyzt_units", "cal_max", "descrip", "qform_code", "sform_code", "quatern_b",
+                      "quatern_c", "quatern_d", "qoffset_x", "qoffset_y", "qoffset_z", "srow_x",
+                      "srow_y", "srow_z", "DATA(md5)", "DATA(diff 1:)"]
+    for item in checked_fields:
+        assert_true(item in stdout)
+
+    fnames2 = [pjoin(DATA_PATH, f)
+              for f in ('example4d.nii.gz', 'example4d.nii.gz')]
+    code, stdout, stderr = run_command(['nib-diff'] + fnames2, check_code=False)
+    assert_equal(stdout, "These files are identical.")
+
+    fnames3 = [pjoin(DATA_PATH, f)
+               for f in ('standard.nii.gz', 'example4d.nii.gz', 'example_nifti2.nii.gz')]
+    code, stdout, stderr = run_command(['nib-diff'] + fnames3, check_code=False)
+    for item in checked_fields:
+        assert_true(item in stdout)
+
+    fnames4 = [pjoin(DATA_PATH, f)
+               for f in ('standard.nii.gz', 'standard.nii.gz', 'standard.nii.gz')]
+    code, stdout, stderr = run_command(['nib-diff'] + fnames4, check_code=False)
+    assert_equal(stdout, "These files are identical.")
+
+    code, stdout, stderr = run_command(['nib-diff', '--dt', 'float64'] + fnames, check_code=False)
+    for item in checked_fields:
+        assert_true(item in stdout)
+
+
+
 @script_test
 def test_nib_ls():
     yield check_nib_ls_example4d
@@ -150,6 +184,11 @@ def test_help():
             assert_equal(stderr, '')
 
 
+@script_test
+def test_nib_diff():
+    yield check_nib_diff_examples
+
+
 @script_test
 def test_nib_nifti_dx():
     # Test nib-nifti-dx script
