@@ -17,12 +17,18 @@ from .volumeutils import (native_code, swapped_code, endian_codes, rec2dict)
 from .openers import ImageOpener
 from .orientations import aff2axcodes
 from .affines import apply_affine
+from .deprecated import deprecate_with_version
 
 try:
     basestring
 except NameError:  # python 3
     basestring = str
 
+warnings.warn("The trackvis interface has been deprecated and will be removed "
+              "in v4.0; please use the 'nibabel.streamlines' interface.",
+              DeprecationWarning,
+              stacklevel=2)
+
 # Definition of trackvis header structure.
 # See http://www.trackvis.org/docs/?subsect=fileformat
 # See https://docs.scipy.org/doc/numpy/reference/arrays.dtypes.html
@@ -99,6 +105,9 @@ class DataError(Exception):
     """
 
 
+@deprecate_with_version('trackvis.read is deprecated; please use '
+                        'nibabel.streamlines.load, instead.',
+                        since='2.5.0', until='4.0.0')
 def read(fileobj, as_generator=False, points_space=None, strict=True):
     ''' Read trackvis file from `fileobj`, return `streamlines`, `header`
 
@@ -254,6 +263,9 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
     return streamlines, hdr
 
 
+@deprecate_with_version('trackvis.write is deprecated; please use '
+                        'nibabel.streamlines.save, instead.',
+                        since='2.5.0', until='4.0.0')
 def write(fileobj, streamlines, hdr_mapping=None, endianness=None,
           points_space=None):
     ''' Write header and `streamlines` to trackvis file `fileobj`
@@ -536,6 +548,9 @@ def _hdr_from_mapping(hdr=None, mapping=None, endianness=native_code):
     return hdr
 
 
+@deprecate_with_version('empty_header is deprecated; please use '
+                        'nibabel.streamlines.TrkFile.create_empty_header, instead.',
+                        since='2.5.0', until='4.0.0')
 def empty_header(endianness=None, version=2):
     ''' Empty trackvis header
 
@@ -590,7 +605,10 @@ def empty_header(endianness=None, version=2):
     return hdr
 
 
-def aff_from_hdr(trk_hdr, atleast_v2=None):
+@deprecate_with_version('aff_from_hdr is deprecated; please use '
+                        'nibabel.streamlines.trk.get_affine_trackvis_to_rasmm, instead.',
+                        since='2.5.0', until='4.0.0')
+def aff_from_hdr(trk_hdr, atleast_v2=True):
     ''' Return voxel to mm affine from trackvis header
 
     Affine is mapping from voxel space to Nifti (RAS) output coordinate
@@ -625,12 +643,6 @@ def aff_from_hdr(trk_hdr, atleast_v2=None):
     origin field to 0. In future, we'll raise an error rather than try and
     estimate the affine from version 1 fields
     '''
-    if atleast_v2 is None:
-        warnings.warn('Defaulting to `atleast_v2` of False.  Future versions '
-                      'will default to True',
-                      FutureWarning,
-                      stacklevel=2)
-        atleast_v2 = False
     if trk_hdr['version'] == 2:
         aff = trk_hdr['vox_to_ras']
         if aff[3, 3] != 0:
@@ -673,7 +685,10 @@ def aff_from_hdr(trk_hdr, atleast_v2=None):
     return aff
 
 
-def aff_to_hdr(affine, trk_hdr, pos_vox=None, set_order=None):
+@deprecate_with_version('aff_to_hdr is deprecated; please use the '
+                        'nibabel.streamlines.TrkFile.affine_to_rasmm property, instead.',
+                        since='2.5.0', until='4.0.0')
+def aff_to_hdr(affine, trk_hdr, pos_vox=True, set_order=True):
     ''' Set affine `affine` into trackvis header `trk_hdr`
 
     Affine is mapping from voxel space to Nifti RAS) output coordinate
@@ -715,18 +730,6 @@ def aff_to_hdr(affine, trk_hdr, pos_vox=None, set_order=None):
     application).  The application also ignores the origin field, and may not
     use the 'image_orientation_patient' field.
     '''
-    if pos_vox is None:
-        warnings.warn('Default for ``pos_vox`` will change to True in '
-                      'future versions of nibabel',
-                      FutureWarning,
-                      stacklevel=2)
-        pos_vox = False
-    if set_order is None:
-        warnings.warn('Default for ``set_order`` will change to True in '
-                      'future versions of nibabel',
-                      FutureWarning,
-                      stacklevel=2)
-        set_order = False
     try:
         version = trk_hdr['version']
     except (KeyError, ValueError):  # dict or structured array
@@ -797,6 +800,9 @@ class TrackvisFile(object):
         relationship between voxels, rasmm and voxmm space (above).
     '''
 
+    @deprecate_with_version('TrackvisFile is deprecated; please use '
+                            'nibabel.streamlines.TrkFile, instead.',
+                            since='2.5.0', until='4.0.0')
     def __init__(self,
                  streamlines,
                  mapping=None,
@@ -836,7 +842,7 @@ class TrackvisFile(object):
         self.filename = (file_like if isinstance(file_like, basestring)
                          else None)
 
-    def get_affine(self, atleast_v2=None):
+    def get_affine(self, atleast_v2=True):
         """ Get affine from header in object
 
         Returns
@@ -853,15 +859,9 @@ class TrackvisFile(object):
         consider it unsafe for version 1 headers, and in future versions of
         nibabel we will raise an error for trackvis headers < version 2.
         """
-        if atleast_v2 is None:
-            warnings.warn('Defaulting to `atleast_v2` of False.  Future '
-                          'versions will default to True',
-                          FutureWarning,
-                          stacklevel=2)
-            atleast_v2 = False
         return aff_from_hdr(self.header, atleast_v2)
 
-    def set_affine(self, affine, pos_vox=None, set_order=None):
+    def set_affine(self, affine, pos_vox=True, set_order=True):
         """ Set affine `affine` into trackvis header
 
         Affine is mapping from voxel space to Nifti RAS) output coordinate
@@ -888,16 +888,4 @@ class TrackvisFile(object):
         -------
         None
         """
-        if pos_vox is None:
-            warnings.warn('Default for ``pos_vox`` will change to True in '
-                          'future versions of nibabel',
-                          FutureWarning,
-                          stacklevel=2)
-            pos_vox = False
-        if set_order is None:
-            warnings.warn('Default for ``set_order`` will change to True in '
-                          'future versions of nibabel',
-                          FutureWarning,
-                          stacklevel=2)
-            set_order = False
         return aff_to_hdr(affine, self.header, pos_vox, set_order)
